# PyUnicodeData

This is a simple package including Unicode UCD.zip and Unihan.zip

# Develop

[Packaging Python Projects](https://packaging.python.org/tutorials/packaging-projects/)

```shell
py -m build
# twine upload --repository testpypi dist/*
twine upload dist/*
```